#ifndef _RemoveFilesDialog_h_
#define _RemoveFilesDialog_h_

// $Id: RemoveFilesDialog.h,v 1.5 2010/04/11 22:41:38 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file RemoveFilesDialog.h
\brief Generic dialog with a FileInfo list
\author Hugo Pereira
\version $Revision: 1.5 $
\date $Date: 2010/04/11 22:41:38 $
*/

#include <cassert>
#include <QList>
#include <QPushButton>
#include <QCheckBox>

#include "CustomDialog.h"
#include "FileSystemModel.h"

class TreeView;
class TextEditor;

//! QDialog used to commit selected files
class RemoveFilesDialog: public CustomDialog
{

    //! Qt meta object
    Q_OBJECT

        public:

        //! constructor
        RemoveFilesDialog( QWidget*, const FileSystemModel::List& files = FileSystemModel::List() );

    // return selected files
    FileSystemModel::List selectedFiles( void ) const;

    //! true if directories are to be removed recursively
    bool recursive( void ) const
    { return recursiveCheckBox_->isChecked(); }

    protected:

    //! list
    TreeView& _list() const
    {
        assert( list_ );
        return *list_;
    }

    //! model
    const FileSystemModel& _model() const
    { return model_; }

    //! model
    FileSystemModel& _model()
    { return model_; }

    protected slots:

    //! update button states
    virtual void _updateButtons( void );

    private:

    //! list of files
    TreeView* list_;

    //! model
    FileSystemModel model_;

    //! true to remove directories recursively
    QCheckBox* recursiveCheckBox_;

    //! clear selection button
    QPushButton* clearSelectionButton_;

};

#endif
